==> code-template-1.0.0.tgz: package/bin/fileHelper.js <==
const path = require('path'),
    fs = require('fs');


/**
 * 删除文件或者路径
 * @param {String} p 文件或目录的路径 
 */
function d(p) {
    var stat = fs.statSync(p);
    if (stat.isFile()) {
        fs.unlinkSync(p);
    } else if (stat.isDirectory()) {
        var files = fs.readdirSync(p);
        files.forEach(f => {
            let filePath = path.join(p, f);
            d(filePath);
        });
        fs.rmdirSync(p);
    }
};


/**
 * 复制文件
 * @param {String} src 源文件路径 
 * @param {String} dest 目标路径
 * @param {boolean} flag 是否打印信息
 */
function cf(src, dest, flag) {
    let data = fs.readFileSync(src, { encoding: 'utf8' });
    fs.writeFileSync(dest, data, { encoding: 'utf8' })
        // var readable = fs.createReadStream(src);
        // // 创建写入流
        // var writable = fs.createWriteStream(dest);
        // // 通过管道来传输流
        //readable.pipe(writable);

    flag && console.log('copy file:', src);
}


//检测文件或者文件夹存在 nodeJS
function fsExistsSync(path) {
    try {
        fs.accessSync(path, fs.F_OK);
    } catch (e) {
        return false;
    }
    return true;
}

/**
 * 复制目录到特定的目录
 * @param {*} p 源路径
 * @param {*} dest 目标路径
 * @param {boolean} flag 是否打印信息
 */
function c(p, dest, flag) {
    if (!fsExistsSync(dest)) {
        fs.mkdirSync(dest);
        flag && console.log('mkdir:', dest);
    }
    let stat = fs.statSync(p);
    let a = p.split('/'); //路径的分段数组
    let lastA = a[a.length - 1];

    if (stat.isFile()) {
        cf(p, path.join(dest, lastA), flag);
    } else if (stat.isDirectory()) {
        let pd = path.join(dest, lastA);
        var files = fs.readdirSync(p);
        files.forEach(f => {
            c(path.join(p, f), pd, flag);
        });
    }
}

/**
 * 复制目录下的所有文件到特定目录
 * @param {String} p 源目录
 * @param {String} dest 目标目录
 * @param {boolean} flag 是否打印信息
 */
function c2(p, dest, flag) {
    if (!fsExistsSync(dest)) {
        fs.mkdirSync(dest);
        flag && console.log('mkdir:', dest);
    }

    var files = fs.readdirSync(p);
    files.forEach(f => {
        c(path.join(p, f), dest, flag);
    });
}


module.exports = {
    delete: d,
    copyFile: cf,
    copy: c,
    exists: fsExistsSync,
    copy2: c2
}

==> code-template-1.0.1.tgz: package/bin/fileHelper.js <==
const path = require('path'),
    fs = require('fs');


/**
 * 删除文件或者路径
 * @param {String} p 文件或目录的路径 
 */
function d(p) {
    var stat = fs.statSync(p);
    if (stat.isFile()) {
        fs.unlinkSync(p);
    } else if (stat.isDirectory()) {
        var files = fs.readdirSync(p);
        files.forEach(f => {
            let filePath = path.join(p, f);
            d(filePath);
        });
        fs.rmdirSync(p);
    }
};


/**
 * 复制文件
 * @param {String} src 源文件路径 
 * @param {String} dest 目标路径
 * @param {boolean} flag 是否打印信息
 */
function cf(src, dest, flag) {
    let data = fs.readFileSync(src, { encoding: 'utf8' });
    //fs.linkSync(dest);
    fs.writeFileSync(dest, data, { encoding: 'utf8' })
        // var readable = fs.createReadStream(src);
        // // 创建写入流
        // var writable = fs.createWriteStream(dest);
        // // 通过管道来传输流
        //readable.pipe(writable);

    flag && console.log('copy file:', src);
}


//检测文件或者文件夹存在 nodeJS
function fsExistsSync(path) {
    try {
        fs.accessSync(path, fs.F_OK);
    } catch (e) {
        return false;
    }
    return true;
}

/**
 * 复制目录到特定的目录
 * @param {*} p 源路径
 * @param {*} dest 目标路径
 * @param {boolean} flag 是否打印信息
 */
function c(p, dest, flag) {
    if (!fsExistsSync(dest)) {
        fs.mkdirSync(dest);
        flag && console.log('mkdir:', dest);
    }
    let stat = fs.statSync(p);
    let destPath = path.join(dest, path.parse(p).base);//输出的文件路径
    if (stat.isFile()) {
        cf(p,destPath , flag);
    } else if (stat.isDirectory()) {
        var files = fs.readdirSync(p);
        files.forEach(f => {
            c(path.join(p, f), destPath, flag);
        });
    }
}

/**
 * 复制目录下的所有文件到特定目录
 * @param {String} p 源目录
 * @param {String} dest 目标目录
 * @param {boolean} flag 是否打印信息
 */
function c2(p, dest, flag) {
    if (!fsExistsSync(dest)) {
        fs.mkdirSync(dest);
        flag && console.log('mkdir:', dest);
    }

    var files = fs.readdirSync(p);
    files.forEach(f => {
        c(path.join(p, f), dest, flag);
    });
}


module.exports = {
    delete: d,
    copyFile: cf,
    copy: c,
    exists: fsExistsSync,
    copy2: c2
}
